Prepare for SoC rework of ARM code:
- rename CONFIG_BOOTBINFUNC into  CONFIG_INIT_CRITICAL
- rename memsetup into lowlevel_init (function name and source files)
diff --git a/board/csb226/Makefile b/board/csb226/Makefile
index ac94642..5b311a9 100644
--- a/board/csb226/Makefile
+++ b/board/csb226/Makefile
@@ -26,7 +26,7 @@
 LIB	= lib$(BOARD).a
 
 OBJS	:= csb226.o flash.o
-SOBJS	:= memsetup.o
+SOBJS	:= lowlevel_init.o
 
 $(LIB):	$(OBJS) $(SOBJS)
 	$(AR) crv $@ $(OBJS) $(SOBJS)
diff --git a/board/csb226/memsetup.S b/board/csb226/lowlevel_init.S
similarity index 98%
rename from board/csb226/memsetup.S
rename to board/csb226/lowlevel_init.S
index 68577ca..aa9dcba 100644
--- a/board/csb226/memsetup.S
+++ b/board/csb226/lowlevel_init.S
@@ -3,7 +3,7 @@
  *
  * NOTE: I haven't clean this up considerably, just enough to get it
  * running. See hal_platform_setup.h for the source. See
  * board/cradle/memsetup.S for another PXA250 setup that is
  * much cleaner.
  *
  * See file CREDITS for list of people who contributed to this
@@ -46,8 +46,8 @@
  * 	Memory setup
  */
 
-.globl memsetup
-memsetup:
+.globl lowlevel_init
+lowlevel_init:
 
     mov      r10, lr
 
@@ -429,9 +429,9 @@
 #endif
 
 	/* ---------------------------------------------------------------- */
-	/* End memsetup                                                     */
+	/* End lowlevel_init                                                     */
 	/* ---------------------------------------------------------------- */
 
-endmemsetup:
+endlowlevel_init:
 
     mov     pc, lr
@@ -3,7 +3,7 @@
  * NOTE: I haven't clean this up considerably, just enough to get it
  * running. See hal_platform_setup.h for the source. See
- * board/cradle/memsetup.S for another PXA250 setup that is
+ * board/cradle/lowlevel_init.S for another PXA250 setup that is
  * much cleaner.
  *